Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(433)

Unified Diff: Tools/DumpRenderTree/chromium/TestRunner/src/TestRunner.h

Issue 14460010: Implement the Blink part of the Device Motion API. (Closed) Base URL: https://chromium.googlesource.com/chromium/blink.git@master
Patch Set: fixed add-listener-from-callback-expected.txt Created 7 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: Tools/DumpRenderTree/chromium/TestRunner/src/TestRunner.h
diff --git a/Tools/DumpRenderTree/chromium/TestRunner/src/TestRunner.h b/Tools/DumpRenderTree/chromium/TestRunner/src/TestRunner.h
index 7e5f6e7c5c79c9180914230938ae91f5a2e8b6cf..4b8574cc4f362d089f4bbb81abc4a96ca328d361 100644
--- a/Tools/DumpRenderTree/chromium/TestRunner/src/TestRunner.h
+++ b/Tools/DumpRenderTree/chromium/TestRunner/src/TestRunner.h
@@ -270,7 +270,9 @@ private:
void enableAutoResizeMode(const CppArgumentList&, CppVariant*);
void disableAutoResizeMode(const CppArgumentList&, CppVariant*);
- // DeviceOrientation related functions
+ // DeviceOrientation / DeviceMotion related functions
+ void enableMockDeviceMotion(const CppArgumentList&, CppVariant*);
+ void fireMockDeviceMotion(const CppArgumentList&, CppVariant*);
void setMockDeviceOrientation(const CppArgumentList&, CppVariant*);
void didAcquirePointerLock(const CppArgumentList&, CppVariant*);

Powered by Google App Engine
This is Rietveld 408576698